@@ -18,7 +18,7 @@ Yahoo::Marketing::KeywordResearchService - an object that provides operations fo
 
 See EWS documentation online for available SOAP methods:
 
-http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/KeywordResearchService.asp
+L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/KeywordResearchService.asp>
 
 Also see perldoc Yahoo::Marketing::Service for functionality common to all service modules.
 
